Struct aptos_cli_common::GasOptions
source · [−]Expand description
Gas price options for manipulating how to prioritize transactions
Fields
gas_unit_price: u64Amount to increase gas bid by for a transaction
Defaults to 1 coin per gas unit
max_gas: u64Maximum gas to be used to send a transaction
Defaults to 1000 gas units