Struct aptos_cli_common::WriteTransactionOptions
source · [−]pub struct WriteTransactionOptions {
pub private_key_options: PrivateKeyInputOptions,
pub rest_options: RestOptions,
pub max_gas: u64,
}Expand description
Options specific to submitting a private key to the Rest endpoint
Fields
private_key_options: PrivateKeyInputOptionsrest_options: RestOptionsmax_gas: u64Maximum gas to be used to publish the package
Defaults to 1000 gas units
Implementations
sourceimpl WriteTransactionOptions
impl WriteTransactionOptions
sourcepub async fn chain_id(&self, profile: &str) -> CliTypedResult<ChainId>
pub async fn chain_id(&self, profile: &str) -> CliTypedResult<ChainId>
Retrieve the chain id from onchain via the Rest API