pub struct GasOptions {
    pub gas_unit_price: u64,
    pub max_gas: u64,
}
Gas price options for manipulating how to prioritize transactions

Fields

gas_unit_price: u64

Amount to increase gas bid by for a transaction

Defaults to 1 coin per gas unit

max_gas: u64

Maximum gas to be used to send a transaction

Defaults to 1000 gas units